@@ -1,4 +1,4 @@
-# Copyright 2019 Wingify Software Pvt. Ltd.
+# Copyright 2019-2021 Wingify Software Pvt. Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,27 +21,11 @@ from .empty_object_schema import EMPTY_OBJECT
 
 
 SETTINGS_FILE_SCHEMA = {
-    'type': 'object',
-    'properties': {
-        'version': {
-            'type': ['number', 'string']
-        },
-        'accountId': {
-            'type': ['number', 'string']
-        },
-        'campaigns': {
-            'if': {
-                'type': 'array'
-            },
-            'then': {
-                'items': CAMPAIGN
-            },
-            'else': EMPTY_OBJECT
-        }
+    "type": "object",
+    "properties": {
+        "version": {"type": ["number", "string"]},
+        "accountId": {"type": ["number", "string"]},
+        "campaigns": {"if": {"type": "array"}, "then": {"items": CAMPAIGN}, "else": EMPTY_OBJECT},
     },
-    'required': [
-        'version',
-        'accountId',
-        'campaigns'
-    ]
+    "required": ["version", "accountId", "campaigns"],
 }
